[Bedework-commit] r423 - in trunk/calendar3: caldav/src/edu/rpi/cct/uwcal/caldav caldav/src/edu/rpi/cct/uwcal/caldav/calquery caldav/src/edu/rpi/cct/uwcal/caldav/filter calsvc/src/org/bedework/calsvc davdefs/src/org/bedework/davdefs test/caldavTestData/eg test/caldavTestData/eg/content test/src/org/bedework/tests/caldav webcommon/src/org/bedework/webcommon/subs webcommon/src/org/bedework/webcommon/views

svnadmin at bedework.org svnadmin at bedework.org
Sun Apr 30 23:48:35 EDT 2006


Author: douglm
Date: 2006-04-30 23:48:26 -0400 (Sun, 30 Apr 2006)
New Revision: 423

Added:
   trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/LimitFreebusySet.java
   trunk/calendar3/test/caldavTestData/eg/content/eg15.xml
   trunk/calendar3/test/caldavTestData/eg/content/eg20.xml
   trunk/calendar3/test/caldavTestData/eg/eg20.test
Modified:
   trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/ReportMethod.java
   trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/CalendarData.java
   trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/CompFilter.java
   trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/Filter.java
   trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/ParamFilter.java
   trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/PropFilter.java
   trunk/calendar3/calsvc/src/org/bedework/calsvc/CalSvc.java
   trunk/calendar3/davdefs/src/org/bedework/davdefs/CaldavTags.java
   trunk/calendar3/test/src/org/bedework/tests/caldav/TestCalDav.java
   trunk/calendar3/webcommon/src/org/bedework/webcommon/subs/GetSubscriptionsAction.java
   trunk/calendar3/webcommon/src/org/bedework/webcommon/views/AddViewAction.java
   trunk/calendar3/webcommon/src/org/bedework/webcommon/views/FetchViewAction.java
Log:
Updates to caldav support to bring it closer to draft 12
Fixes to getSubscriptions to return calendar object

Modified: trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/ReportMethod.java
===================================================================
--- trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/ReportMethod.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/ReportMethod.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -75,9 +75,9 @@
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Iterator;
-import java.util.Vector;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
@@ -98,7 +98,7 @@
   private PropFindMethod.PropRequest preq;
   private CalendarData caldata;
   private Filter filter;
-  private Vector hrefs;
+  private ArrayList hrefs;
 
   private final static int reportTypeQuery = 0;
   private final static int reportTypeMultiGet = 1;
@@ -255,7 +255,7 @@
             }
 
             if (hrefs == null) {
-              hrefs = new Vector();
+              hrefs = new ArrayList();
             }
 
             hrefs.add(href);
@@ -371,7 +371,7 @@
         status = wde.getStatusCode();
       }
     } else if (reportType == reportTypeMultiGet) {
-      nodes = new Vector();
+      nodes = new ArrayList();
 
       if (hrefs != null) {
         Iterator it = hrefs.iterator();

Modified: trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/CalendarData.java
===================================================================
--- trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/CalendarData.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/CalendarData.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -89,8 +89,9 @@
  */
 public class CalendarData {
   /*
-      <!ELEMENT calendar-data ((comp?, (expand-recurrence-set |
-                                       limit-recurrence-set)?) |
+      <!ELEMENT calendar-data ((comp?, (expand |
+                                           limit-recurrence-set)?,
+                                           limit-freebusy-set?) |
                           #PCDATA)?>
 
          pcdata is for response
@@ -126,6 +127,7 @@
   private Comp comp;
   private ExpandRecurrenceSet ers;
   private LimitRecurrenceSet lrs;
+  private LimitFreebusySet lfs;
 
   /** Constructor
    *
@@ -163,6 +165,13 @@
     return lrs;
   }
 
+  /**
+   * @return LimitFreebusySet
+   */
+  public LimitFreebusySet getLfs() {
+    return lfs;
+  }
+
   /** The given node must be the Filter element
    *
    * @param nd
@@ -209,8 +218,7 @@
           }
 
           comp = parseComp(curnode);
-        } else if (MethodBase.nodeMatches(curnode, CaldavTags.expandRecurrenceSet) ||
-                   MethodBase.nodeMatches(curnode, CaldavTags.expand)) {
+        } else if (MethodBase.nodeMatches(curnode, CaldavTags.expand)) {
           if (ers != null) {
             throw new WebdavBadRequest();
           }
@@ -224,6 +232,13 @@
 
           lrs = new LimitRecurrenceSet();
            parseTimeRange(curnode, lrs);
+        } else if (MethodBase.nodeMatches(curnode, CaldavTags.limitFreebusySet)) {
+          if (lfs != null) {
+            throw new WebdavBadRequest();
+          }
+
+          lfs = new LimitFreebusySet();
+           parseTimeRange(curnode, lfs);
         } else {
           throw new WebdavBadRequest();
         }

Added: trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/LimitFreebusySet.java
===================================================================
--- trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/LimitFreebusySet.java	                        (rev 0)
+++ trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/calquery/LimitFreebusySet.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -0,0 +1,96 @@
+/*
+ Copyright (c) 2000-2005 University of Washington.  All rights reserved.
+
+ Redistribution and use of this distribution in source and binary forms,
+ with or without modification, are permitted provided that:
+
+   The above copyright notice and this permission notice appear in
+   all copies and supporting documentation;
+
+   The name, identifiers, and trademarks of the University of Washington
+   are not used in advertising or publicity without the express prior
+   written permission of the University of Washington;
+
+   Recipients acknowledge that this distribution is made available as a
+   research courtesy, "as is", potentially with defects, without
+   any obligation on the part of the University of Washington to
+   provide support, services, or repair;
+
+   THE UNIVERSITY OF WASHINGTON DISCLAIMS ALL WARRANTIES, EXPRESS OR
+   IMPLIED, WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT LIMITATION
+   ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+   PARTICULAR PURPOSE, AND IN NO EVENT SHALL THE UNIVERSITY OF
+   WASHINGTON BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
+   DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
+   PROFITS, WHETHER IN AN ACTION OF CONTRACT, TORT (INCLUDING
+   NEGLIGENCE) OR STRICT LIABILITY, ARISING OUT OF OR IN CONNECTION WITH
+   THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+/* **********************************************************************
+    Copyright 2005 Rensselaer Polytechnic Institute. All worldwide rights reserved.
+
+    Redistribution and use of this distribution in source and binary forms,
+    with or without modification, are permitted provided that:
+       The above copyright notice and this permission notice appear in all
+        copies and supporting documentation;
+
+        The name, identifiers, and trademarks of Rensselaer Polytechnic
+        Institute are not used in advertising or publicity without the
+        express prior written permission of Rensselaer Polytechnic Institute;
+
+    DISCLAIMER: The software is distributed" AS IS" without any express or
+    implied warranty, including but not limited to, any implied warranties
+    of merchantability or fitness for a particular purpose or any warrant)'
+    of non-infringement of any current or pending patent rights. The authors
+    of the software make no representations about the suitability of this
+    software for any particular purpose. The entire risk as to the quality
+    and performance of the software is with the user. Should the software
+    prove defective, the user assumes the cost of all necessary servicing,
+    repair or correction. In particular, neither Rensselaer Polytechnic
+    Institute, nor the authors of the software are liable for any indirect,
+    special, consequential, or incidental damages related to the software,
+    to the maximum extent the law permits.
+*/
+
+package edu.rpi.cct.uwcal.caldav.calquery;
+
+import org.bedework.calfacade.BwDateTime;
+
+import edu.rpi.cct.uwcal.caldav.TimeRange;
+
+import org.apache.log4j.Logger;
+
+/**
+ * @author Mike Douglass douglm @ rpi.edu
+ */
+public class LimitFreebusySet extends TimeRange {
+  /** Constructor
+   */
+  public LimitFreebusySet() {
+  }
+
+  /** Constructor
+   *
+   * @param start
+   * @param end
+   */
+  public LimitFreebusySet(BwDateTime start, BwDateTime end) {
+    super(start, end);
+  }
+
+  /**
+   * @param log
+   * @param indent
+   */
+  public void dump(Logger log, String indent) {
+    StringBuffer sb = new StringBuffer(indent);
+
+    sb.append("<limit-freebusy-set ");
+    super.toStringSegment(sb);
+    sb.append("/>");
+
+    log.debug(sb.toString());
+  }
+}
+
+

Modified: trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/CompFilter.java
===================================================================
--- trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/Filter.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/Filter.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -491,7 +491,7 @@
   }
 
   /** The given node must be a comp-filter element
-   *    <!ELEMENT comp-filter (is-defined | time-range)?
+   *    <!ELEMENT comp-filter (is-not-defined | time-range)?
    *                          comp-filter* prop-filter*>
    *
    *    <!ATTLIST comp-filter name CDATA #REQUIRED>
@@ -520,14 +520,14 @@
               curnode.getLocalName());
         }
 
-        if (MethodBase.nodeMatches(curnode, CaldavTags.isDefined)) {
+        if (MethodBase.nodeMatches(curnode, CaldavTags.isNotDefined)) {
           if (cf.getTimeRange() != null) {
             throw new WebdavBadRequest();
           }
 
-          cf.setIsDefined(true);
+          cf.setIsNotDefined(true);
         } else if (MethodBase.nodeMatches(curnode, CaldavTags.timeRange)) {
-          if (cf.getIsDefined()) {
+          if (cf.getIsNotDefined()) {
             throw new WebdavBadRequest();
           }
 
@@ -567,7 +567,7 @@
   }
 
   /* The given node must be a prop-filter element
-   *    <!ELEMENT prop-filter (is-defined | time-range | text-match)?
+   *    <!ELEMENT prop-filter (is-not-defined | time-range | text-match)?
    *                            param-filter*>
    *
    *    <!ATTLIST prop-filter name CDATA #REQUIRED>
@@ -612,8 +612,8 @@
           idTrTm = true;
 
           // one of is-defined | time-range | text-match
-          if (MethodBase.nodeMatches(curnode, CaldavTags.isDefined)) {
-            pf.setIsDefined(true);
+          if (MethodBase.nodeMatches(curnode, CaldavTags.isNotDefined)) {
+            pf.setIsNotDefined(true);
           } else if (MethodBase.nodeMatches(curnode, CaldavTags.timeRange)) {
             pf.setTimeRange(CalDavParseUtil.parseTimeRange(curnode,
                 intf.getSvci().getTimezones()));
@@ -624,10 +624,6 @@
               return null;
             }
           } else {
-            // Effectively is-defined
-            pf.setIsDefined(true);
-//          status = HttpServletResponse.SC_BAD_REQUEST;
-//          return null;
           }
         }
       }
@@ -641,7 +637,7 @@
   }
 
   /* The given node must be a param-filter element
-   *    <!ELEMENT param-filter (is-defined | text-match) >
+   *    <!ELEMENT param-filter (is-not-defined | text-match) >
    *
    *    <!ATTLIST param-filter name CDATA #REQUIRED>
    */
@@ -661,7 +657,7 @@
             child.getLocalName());
     }
 
-    if (MethodBase.nodeMatches(child, CaldavTags.isDefined)) {
+    if (MethodBase.nodeMatches(child, CaldavTags.isNotDefined)) {
       return new ParamFilter(name, true);
     }
 

Modified: trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/ParamFilter.java
===================================================================
--- trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/ParamFilter.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/ParamFilter.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -64,18 +64,18 @@
 public class ParamFilter {
   private String name;
 
-  private boolean isDefined;
+  private boolean isNotDefined;
 
   private TextMatch match;
 
   /** Constructor
    *
    * @param name
-   * @param isDefined
+   * @param isNotDefined
    */
-  public ParamFilter(String name, boolean isDefined) {
+  public ParamFilter(String name, boolean isNotDefined) {
     this.name = name;
-    this.isDefined = isDefined;
+    this.isNotDefined = isNotDefined;
   }
 
   /** Constructor
@@ -105,15 +105,15 @@
   /**
    * @param val
    */
-  public void setIsDefined(boolean val) {
-    isDefined = val;
+  public void setIsNotDefined(boolean val) {
+    isNotDefined = val;
   }
 
   /**
    * @return boolean isdefined value
    */
-  public boolean getIsDefined() {
-    return isDefined;
+  public boolean getIsNotDefined() {
+    return isNotDefined;
   }
 
   /**
@@ -143,8 +143,8 @@
     sb.append(">\n");
     log.debug(sb.toString());
 
-    if (isDefined) {
-      log.debug(indent + "  " + "<is-defined/>\n");
+    if (isNotDefined) {
+      log.debug(indent + "  " + "<is-not-defined/>\n");
     } else {
       match.dump(log, indent + "  ");
     }

Modified: trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/PropFilter.java
===================================================================
--- trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/PropFilter.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/PropFilter.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -75,7 +75,7 @@
   /* Name of property */
   private String name;
 
-  private boolean isDefined;
+  private boolean isNotDefined;
 
   private TimeRange timeRange;
 
@@ -94,11 +94,11 @@
   /** Constructor
    *
    * @param name
-   * @param isDefined
+   * @param isNotDefined
    */
-  public PropFilter(String name, boolean isDefined) {
+  public PropFilter(String name, boolean isNotDefined) {
     this.name = name;
-    this.isDefined = isDefined;
+    this.isNotDefined = isNotDefined;
   }
 
   /** Constructor
@@ -138,15 +138,15 @@
   /**
    * @param val
    */
-  public void setIsDefined(boolean val) {
-    isDefined = val;
+  public void setIsNotDefined(boolean val) {
+    isNotDefined = val;
   }
 
   /**
    * @return boolean
    */
-  public boolean getIsDefined() {
-    return isDefined;
+  public boolean getIsNotDefined() {
+    return isNotDefined;
   }
 
   /**
@@ -215,13 +215,9 @@
       Property prop = pl.getProperty(getName());
 
       if (prop == null) {
-        return false;
+        return getIsNotDefined();
       }
 
-      if (getIsDefined()) {
-        return true;
-      }
-
       TextMatch match = getMatch();
       if (match != null) {
         return match.matches(prop.getValue());
@@ -252,8 +248,8 @@
     sb.append("\">\n");
     log.debug(sb.toString());
 
-    if (isDefined) {
-      log.debug(indent + "  " + "<is-defined/>\n");
+    if (isNotDefined) {
+      log.debug(indent + "  " + "<is-not-defined/>\n");
     } else if (timeRange != null) {
       timeRange.dump(log, indent + "  ");
     } else {

Modified: trunk/calendar3/calsvc/src/org/bedework/calsvc/CalSvc.java
===================================================================
--- trunk/calendar3/calsvc/src/org/bedework/calsvc/CalSvc.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/calsvc/src/org/bedework/calsvc/CalSvc.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -1004,7 +1004,16 @@
   }
 
   public Collection getSubscriptions() throws CalFacadeException {
-    return getPreferences().getSubscriptions();
+    Collection c = getPreferences().getSubscriptions();
+
+    Iterator it = c.iterator();
+    while (it.hasNext()) {
+      BwSubscription sub = (BwSubscription)it.next();
+
+      getSubCalendar(sub);
+    }
+
+    return c;
   }
 
   public BwSubscription getSubscription(int id) throws CalFacadeException {

Modified: trunk/calendar3/davdefs/src/org/bedework/davdefs/CaldavTags.java
===================================================================
--- trunk/calendar3/davdefs/src/org/bedework/davdefs/CaldavTags.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/davdefs/src/org/bedework/davdefs/CaldavTags.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -101,14 +101,10 @@
   public static final QName compFilter = new QName(caldavNamespace,
                                                    "comp-filter");
 
-  /** >= draft 9   */
+  /**   */
   public static final QName expand = new QName(caldavNamespace,
                                                "expand");
 
-  /** < draft 9   */
-  public static final QName expandRecurrenceSet = new QName(caldavNamespace,
-                                                            "expand-recurrence-set");
-
   /**   */
   public static final QName filter = new QName(caldavNamespace,
                                                "filter");
@@ -118,12 +114,16 @@
                                                       "free-busy-query");
 
   /**   */
-  public static final QName isDefined = new QName(caldavNamespace,
-                                                  "is-defined");
+  public static final QName isNotDefined = new QName(caldavNamespace,
+                                                     "is-not-defined");
 
   /**   */
+  public static final QName limitFreebusySet = new QName(caldavNamespace,
+                                                         "limit-freebusy-set");
+
+  /**   */
   public static final QName limitRecurrenceSet = new QName(caldavNamespace,
-                                                            "limit-recurrence-set");
+                                                           "limit-recurrence-set");
 
   /**   */
   public static final QName mkcalendar = new QName(caldavNamespace,

Added: trunk/calendar3/test/caldavTestData/eg/content/eg15.xml
===================================================================
--- trunk/calendar3/test/caldavTestData/eg/content/eg15.xml	                        (rev 0)
+++ trunk/calendar3/test/caldavTestData/eg/content/eg15.xml	2006-05-01 03:48:26 UTC (rev 423)
@@ -0,0 +1,11 @@
+<?xml version="1.0" encoding="utf-8" ?>
+<D:propfind xmlns:D="DAV:" xmlns:C="urn:ietf:params:xml:ns:caldav">
+  <D:prop>
+    <D:getetag/>
+    <D:owner/>
+    <D:acl/>
+    <C:calendar-timezone/>
+    <C:max-resource-size/>
+  </D:prop>
+</D:propfind>
+

Added: trunk/calendar3/test/caldavTestData/eg/content/eg20.xml
===================================================================
--- trunk/calendar3/test/caldavTestData/eg/content/eg20.xml	                        (rev 0)
+++ trunk/calendar3/test/caldavTestData/eg/content/eg20.xml	2006-05-01 03:48:26 UTC (rev 423)
@@ -0,0 +1,6 @@
+<?xml version="1.0" encoding="utf-8" ?>
+<C:free-busy-query xmlns:C="urn:ietf:params:xml:ns:caldav">
+  <C:time-range start="@NOW@"
+                  end="@NEXTWEEK@"/>
+</C:free-busy-query>
+

Added: trunk/calendar3/test/caldavTestData/eg/eg20.test
===================================================================
--- trunk/calendar3/test/caldavTestData/eg/eg20.test	                        (rev 0)
+++ trunk/calendar3/test/caldavTestData/eg/eg20.test	2006-05-01 03:48:26 UTC (rev 423)
@@ -0,0 +1,12 @@
+DESCRIPTION: report free/busy
+
+METHOD: REPORT
+
+AUTH: true
+
+HEADER: Depth: 0
+
+CONTENTTYPE: text/xml
+
+CONTENTFILE: content/eg20.xml
+

Modified: trunk/calendar3/test/src/org/bedework/tests/caldav/TestCalDav.java
===================================================================
--- trunk/calendar3/test/src/org/bedework/tests/caldav/TestCalDav.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/test/src/org/bedework/tests/caldav/TestCalDav.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -82,7 +82,6 @@
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.TreeSet;
-import java.util.Vector;
 
 /** Try to fire requests at this thing.
  *

Modified: trunk/calendar3/webcommon/src/org/bedework/webcommon/subs/GetSubscriptionsAction.java
===================================================================
--- trunk/calendar3/webcommon/src/org/bedework/webcommon/subs/GetSubscriptionsAction.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/webcommon/src/org/bedework/webcommon/subs/GetSubscriptionsAction.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -79,9 +79,9 @@
                          HttpServletResponse response,
                          BwSession sess,
                          BwActionFormBase form) throws Throwable {
-    CalSvcI svc = form.fetchSvci();
+    //CalSvcI svc = form.fetchSvci();
 
-    form.setSubscriptions(svc.getSubscriptions());
+    //form.setSubscriptions(svc.getSubscriptions());
 
     return "success";
   }

Modified: trunk/calendar3/webcommon/src/org/bedework/webcommon/views/AddViewAction.java
===================================================================
--- trunk/calendar3/webcommon/src/org/bedework/webcommon/views/AddViewAction.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/webcommon/src/org/bedework/webcommon/views/AddViewAction.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -114,7 +114,7 @@
     }
 
     form.setView(view);
-    form.setSubscriptions(svc.getSubscriptions());
+    //form.setSubscriptions(svc.getSubscriptions());
 
     return "success";
   }

Modified: trunk/calendar3/webcommon/src/org/bedework/webcommon/views/FetchViewAction.java
===================================================================
--- trunk/calendar3/webcommon/src/org/bedework/webcommon/views/FetchViewAction.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/webcommon/src/org/bedework/webcommon/views/FetchViewAction.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -103,7 +103,7 @@
     }
 
     form.setView(view);
-    form.setSubscriptions(svc.getSubscriptions());
+    //form.setSubscriptions(svc.getSubscriptions());
 
     String reqpar = getReqPar(request, "delete");
 



More information about the Bedework-commit mailing list
--- trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/CompFilter.java	2006-04-28 21:04:52 UTC (rev 422)
+++ trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/CompFilter.java	2006-05-01 03:48:26 UTC (rev 423)
@@ -71,7 +71,7 @@
   /* Name of component VEVENT etc */
   private String name;
 
-  private boolean isDefined;
+  private boolean isNotDefined;
 
   private TimeRange timeRange;
 
@@ -103,15 +103,15 @@
   /**
    * @param val
    */
-  public void setIsDefined(boolean val) {
-    isDefined = val;
+  public void setIsNotDefined(boolean val) {
+    isNotDefined = val;
   }
 
   /**
    * @return boolean isdefined value
    */
-  public boolean getIsDefined() {
-    return isDefined;
+  public boolean getIsNotDefined() {
+    return isNotDefined;
   }
 
   /**
@@ -202,8 +202,8 @@
     sb.append("\">");
     log.debug(sb.toString());
 
-    if (isDefined) {
-      log.debug(indent + "  " + "<is-defined/>");
+    if (isNotDefined) {
+      log.debug(indent + "  " + "<is-not-defined/>");
     } else if (timeRange != null) {
       timeRange.dump(log, indent + "  ");
     }
@@ -103,15 +103,15 @@
 
   /**
-   * @return boolean isdefined value
+   * @return boolean isNotDefined value
    */

Modified: trunk/calendar3/caldav/src/edu/rpi/cct/uwcal/caldav/filter/Filter.java
===================================================================